@@ -4,17 +4,14 @@ use warnings;
 use Carp;
 use Data::Dumper;
 use Time::HiRes 'gettimeofday';
-use Scalar::Util 'looks_like_number';
 use base 'Exporter';
 our @EXPORT = qw( DEBUG DEBUG_DUMP LEAK_TRACK );
 our @EXPORT_OK = qw( debug stacktrace );
 
 
-our $level = 0; # needed global for source filter
-
-my %level4package;           # package specific level
+our $level; # needed global for source filter
+my %level4package;
 my $debug_prefix = 'DEBUG:'; # default prefix
-my $debug_sub;               # alternative sub to STDERR output
 
 
 ##############################################################
@@ -27,19 +24,21 @@ my $debug_sub;               # alternative sub to STDERR output
 sub import {
 	my $class = shift;
 	my (@export,@level);
-	for (@_) {
-		if ( ref eq 'CODE' ) {
-			# set debug sub
-			$debug_sub = $_;
-		} elsif ( m{[=\*]} || m{^\d} || m{::}  ) {
+	foreach (@_) {
+		if ( m{[=\*]} || m{^\d} || m{::}  ) {
 			push @level,$_
 		} else {
 			push @export,$_
 		}
 	}
-	$class->level(@level) if @level;
-	$class->export_to_level(1,@export) if @export;
-	$class->export_to_level(1) if ! @export && ! @level;
+	if (@level) {
+		$class->level(@level)
+	} elsif (@export) {
+		$class->export_to_level(1,@export)
+	} elsif (!@_) {
+		# export defaults only
+		$class->export_to_level(1)
+	}
 }
 
 ##############################################################
@@ -73,7 +72,7 @@ sub level {
 					$level4package{$_} = $l;
 					$level4package{$_.'::'} = $l if $below;
 				}
-			}
+			} 
 		}
 
 	} else {
@@ -115,8 +114,7 @@ sub set_prefix {
 
 ################################################################
 # write debug output if debugging enabled for caller
-# Args: ?$level, ( $message | $fmt,@arg )
-#  $level: if first arg is number it's interpreted as debug level
+# Args: $message | $fmt,@arg
 #   $message: single message
 #   $fmt: format for sprintf
 #   @arg: arguments for sprintf after format
@@ -124,19 +122,13 @@ sub set_prefix {
 ################################################################
 sub DEBUG { goto &debug }
 sub debug {
-	my $level = __PACKAGE__->level || return;
-	my $prefix = $debug_prefix;
-	if (@_>1 and looks_like_number($_[0])) {
-		my $when = shift;
-		return if $when>$level;
-		$prefix .= "<$when>";
-	}
+	return unless __PACKAGE__->level;
 	my ($msg,@arg) = @_;
 	return if !defined($msg);
 	if ( 1 || $msg !~ m{^\w+:} ) {
 		# Message hat keinen eigenen "Prefix:", also mit Funktion[Zeile] prefixen
-		my ($sub) = (caller(1))[3];
-		my $line  = (caller(0))[2];
+		my ($pkg,$func,$sub) = (caller(1))[0,1,3];
+		my $line             = (caller(0))[2];
 		$sub =~s{^main::}{} if $sub;
 		$sub ||= 'Main';
 		$msg = "$sub\[$line]: ".$msg;
@@ -148,34 +140,23 @@ sub debug {
 		$msg = sprintf($msg,@arg);
 	}
 
-	# if $debug_sub use this
-	return $debug_sub->($msg) if $debug_sub;
-
 	# alle Zeilen mit DEBUG: prefixen
-	$prefix = sprintf "%.4f %s",scalar(gettimeofday()),$prefix;
+	my $prefix = sprintf "%.4f $debug_prefix", scalar(gettimeofday());
 	$msg = $prefix." ".$msg;
 	$msg =~s{\n}{\n$prefix\t}g;
 	return $msg if defined wantarray; # don't print
-	$msg =~s{[^[:space:][:print:]]}{_}g;
 	print STDERR $msg,"\n";
 }
 
 ################################################################
 # Dumps structure if debugging enabled
-# Args: ?$level,@data
-#  $level: if first arg is number it's interpreted as debug level
+# Args: @data
 #  @data: what to be dumped, if @data>1 will dump \@data, else $data[0]
 # Returns: NONE
 ################################################################
 sub DEBUG_DUMP {
-	my $level = __PACKAGE__->level || return;
-	my $when;
-	if (@_>1 and looks_like_number($_[0])) {
-		$when = shift;
-		return if $when>$level;
-	}
+	return unless __PACKAGE__->level;
 	@_ = Dumper( @_>1 ? \@_:$_[0] );
-	unshift @_,$when if defined $when;
 	goto &debug;
 }
 
@@ -267,7 +248,7 @@ FILTER_ONLY( code => sub {
 	# replace DEBUG(...) with
 	# - if Debug::level around it (faster, because expressions inside debug
 	#   get only evaluated if debugging is active)
-	# - no warnings for expressions, because in often debug messages
+	# - no warnings for expressions, because in often debug messages 
 	#   are quick and dirty
 	# FIXME: do it for DEBUG_DUMP too
 	# cannot use Text::Balanced etc because placeholder might contain ')' which
@@ -277,7 +258,7 @@ FILTER_ONLY( code => sub {
 	{
 		local $_ = $_; # copy
 		while (1) {
-			$code .=
+			$code .= 
 				s{\ADEBUG\s*\(}{}s ? '' :
 				s{\A(.*?[^\w:])DEBUG\s*\(}{}s ? $1 :
 				last;
